summaryrefslogtreecommitdiff
path: root/arch/sparc/linux
diff options
context:
space:
mode:
authorGabe Black <gblack@eecs.umich.edu>2006-03-31 20:31:53 -0500
committerGabe Black <gblack@eecs.umich.edu>2006-03-31 20:31:53 -0500
commit5c79eb04104e6e3dd2fd957c071fef3ceb47b722 (patch)
treed49e5234e732d78e81df453725f787093426e38a /arch/sparc/linux
parent2177d822ce1eecffb685f13468412c99b1e59ecd (diff)
downloadgem5-5c79eb04104e6e3dd2fd957c071fef3ceb47b722.tar.xz
Fixes to SPARC for syscall emulation mode.
arch/sparc/isa/base.isa: arch/sparc/isa/decoder.isa: arch/sparc/isa/formats.isa: arch/sparc/isa/formats/branch.isa: arch/sparc/isa/formats/integerop.isa: arch/sparc/isa/formats/mem.isa: arch/sparc/isa/formats/nop.isa: arch/sparc/isa/formats/trap.isa: arch/sparc/isa/formats/unknown.isa: arch/sparc/isa/includes.isa: arch/sparc/isa/operands.isa: Fixes towards running in syscall emulation mode. arch/sparc/linux/process.cc: Fixed the assert and comment to check that the Num_Syscall_Descs is less than or equal to 284. Why does this assert need to exist anyway? base/loader/elf_object.cc: Cleared out comments about resolved issues. cpu/simple/cpu.cc: Use NNPC for both SPARC and MIPS, instead of just MIPS configs/test/hello_sparc: A test program for SPARC which prints "Hello World!" --HG-- rename : arch/sparc/isa/formats/noop.isa => arch/sparc/isa/formats/nop.isa extra : convert_revision : 10b3e3b9f21c215d809cffa930448007102ba698
Diffstat (limited to 'arch/sparc/linux')
-rw-r--r--arch/sparc/linux/process.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/arch/sparc/linux/process.cc b/arch/sparc/linux/process.cc
index cb056eadc..c7e5f79ca 100644
--- a/arch/sparc/linux/process.cc
+++ b/arch/sparc/linux/process.cc
@@ -356,9 +356,9 @@ SparcLinuxProcess::SparcLinuxProcess(const std::string &name,
stdin_fd, stdout_fd, stderr_fd, argv, envp),
Num_Syscall_Descs(sizeof(syscallDescs) / sizeof(SyscallDesc))
{
// The sparc syscall table must be <= 283 entries because that is all there
// is space for.
- assert(Num_Syscall_Descs <= 283);
+ assert(Num_Syscall_Descs <= 284);
}
@@ -356,9 +356,9 @@ SparcLinuxProcess::SparcLinuxProcess(const std::string &name,
Num_Syscall_Descs(sizeof(syscallDescs) / sizeof(SyscallDesc))
{
- // The sparc syscall table must be <= 283 entries because that is all there
+ // The sparc syscall table must be <= 284 entries because that is all there
// is space for.